// SPDX-License-Identifier: Apache-2.0
// Copyright Authors of Tetragon

//go:build amd64 && linux
// +build amd64,linux

package syscallinfo

import (
	"github.com/cilium/tetragon/pkg/syscallinfo/i386"
	"golang.org/x/sys/unix"
)

var syscallNames = map[int]string{
	unix.SYS_READ:                    "sys_read",
	unix.SYS_WRITE:                   "sys_write",
	unix.SYS_OPEN:                    "sys_open",
	unix.SYS_CLOSE:                   "sys_close",
	unix.SYS_STAT:                    "sys_stat",
	unix.SYS_FSTAT:                   "sys_fstat",
	unix.SYS_LSTAT:                   "sys_lstat",
	unix.SYS_POLL:                    "sys_poll",
	unix.SYS_LSEEK:                   "sys_lseek",
	unix.SYS_MMAP:                    "sys_mmap",
	unix.SYS_MPROTECT:                "sys_mprotect",
	unix.SYS_MUNMAP:                  "sys_munmap",
	unix.SYS_BRK:                     "sys_brk",
	unix.SYS_RT_SIGACTION:            "sys_rt_sigaction",
	unix.SYS_RT_SIGPROCMASK:          "sys_rt_sigprocmask",
	unix.SYS_RT_SIGRETURN:            "sys_rt_sigreturn",
	unix.SYS_IOCTL:                   "sys_ioctl",
	unix.SYS_PREAD64:                 "sys_pread64",
	unix.SYS_PWRITE64:                "sys_pwrite64",
	unix.SYS_READV:                   "sys_readv",
	unix.SYS_WRITEV:                  "sys_writev",
	unix.SYS_ACCESS:                  "sys_access",
	unix.SYS_PIPE:                    "sys_pipe",
	unix.SYS_SELECT:                  "sys_select",
	unix.SYS_SCHED_YIELD:             "sys_sched_yield",
	unix.SYS_MREMAP:                  "sys_mremap",
	unix.SYS_MSYNC:                   "sys_msync",
	unix.SYS_MINCORE:                 "sys_mincore",
	unix.SYS_MADVISE:                 "sys_madvise",
	unix.SYS_SHMGET:                  "sys_shmget",
	unix.SYS_SHMAT:                   "sys_shmat",
	unix.SYS_SHMCTL:                  "sys_shmctl",
	unix.SYS_DUP:                     "sys_dup",
	unix.SYS_DUP2:                    "sys_dup2",
	unix.SYS_PAUSE:                   "sys_pause",
	unix.SYS_NANOSLEEP:               "sys_nanosleep",
	unix.SYS_GETITIMER:               "sys_getitimer",
	unix.SYS_ALARM:                   "sys_alarm",
	unix.SYS_SETITIMER:               "sys_setitimer",
	unix.SYS_GETPID:                  "sys_getpid",
	unix.SYS_SENDFILE:                "sys_sendfile",
	unix.SYS_SOCKET:                  "sys_socket",
	unix.SYS_CONNECT:                 "sys_connect",
	unix.SYS_ACCEPT:                  "sys_accept",
	unix.SYS_SENDTO:                  "sys_sendto",
	unix.SYS_RECVFROM:                "sys_recvfrom",
	unix.SYS_SENDMSG:                 "sys_sendmsg",
	unix.SYS_RECVMSG:                 "sys_recvmsg",
	unix.SYS_SHUTDOWN:                "sys_shutdown",
	unix.SYS_BIND:                    "sys_bind",
	unix.SYS_LISTEN:                  "sys_listen",
	unix.SYS_GETSOCKNAME:             "sys_getsockname",
	unix.SYS_GETPEERNAME:             "sys_getpeername",
	unix.SYS_SOCKETPAIR:              "sys_socketpair",
	unix.SYS_SETSOCKOPT:              "sys_setsockopt",
	unix.SYS_GETSOCKOPT:              "sys_getsockopt",
	unix.SYS_CLONE:                   "sys_clone",
	unix.SYS_FORK:                    "sys_fork",
	unix.SYS_VFORK:                   "sys_vfork",
	unix.SYS_EXECVE:                  "sys_execve",
	unix.SYS_EXIT:                    "sys_exit",
	unix.SYS_WAIT4:                   "sys_wait4",
	unix.SYS_KILL:                    "sys_kill",
	unix.SYS_UNAME:                   "sys_uname",
	unix.SYS_SEMGET:                  "sys_semget",
	unix.SYS_SEMOP:                   "sys_semop",
	unix.SYS_SEMCTL:                  "sys_semctl",
	unix.SYS_SHMDT:                   "sys_shmdt",
	unix.SYS_MSGGET:                  "sys_msgget",
	unix.SYS_MSGSND:                  "sys_msgsnd",
	unix.SYS_MSGRCV:                  "sys_msgrcv",
	unix.SYS_MSGCTL:                  "sys_msgctl",
	unix.SYS_FCNTL:                   "sys_fcntl",
	unix.SYS_FLOCK:                   "sys_flock",
	unix.SYS_FSYNC:                   "sys_fsync",
	unix.SYS_FDATASYNC:               "sys_fdatasync",
	unix.SYS_TRUNCATE:                "sys_truncate",
	unix.SYS_FTRUNCATE:               "sys_ftruncate",
	unix.SYS_GETDENTS:                "sys_getdents",
	unix.SYS_GETCWD:                  "sys_getcwd",
	unix.SYS_CHDIR:                   "sys_chdir",
	unix.SYS_FCHDIR:                  "sys_fchdir",
	unix.SYS_RENAME:                  "sys_rename",
	unix.SYS_MKDIR:                   "sys_mkdir",
	unix.SYS_RMDIR:                   "sys_rmdir",
	unix.SYS_CREAT:                   "sys_creat",
	unix.SYS_LINK:                    "sys_link",
	unix.SYS_UNLINK:                  "sys_unlink",
	unix.SYS_SYMLINK:                 "sys_symlink",
	unix.SYS_READLINK:                "sys_readlink",
	unix.SYS_CHMOD:                   "sys_chmod",
	unix.SYS_FCHMOD:                  "sys_fchmod",
	unix.SYS_CHOWN:                   "sys_chown",
	unix.SYS_FCHOWN:                  "sys_fchown",
	unix.SYS_LCHOWN:                  "sys_lchown",
	unix.SYS_UMASK:                   "sys_umask",
	unix.SYS_GETTIMEOFDAY:            "sys_gettimeofday",
	unix.SYS_GETRLIMIT:               "sys_getrlimit",
	unix.SYS_GETRUSAGE:               "sys_getrusage",
	unix.SYS_SYSINFO:                 "sys_sysinfo",
	unix.SYS_TIMES:                   "sys_times",
	unix.SYS_PTRACE:                  "sys_ptrace",
	unix.SYS_GETUID:                  "sys_getuid",
	unix.SYS_SYSLOG:                  "sys_syslog",
	unix.SYS_GETGID:                  "sys_getgid",
	unix.SYS_SETUID:                  "sys_setuid",
	unix.SYS_SETGID:                  "sys_setgid",
	unix.SYS_GETEUID:                 "sys_geteuid",
	unix.SYS_GETEGID:                 "sys_getegid",
	unix.SYS_SETPGID:                 "sys_setpgid",
	unix.SYS_GETPPID:                 "sys_getppid",
	unix.SYS_GETPGRP:                 "sys_getpgrp",
	unix.SYS_SETSID:                  "sys_setsid",
	unix.SYS_SETREUID:                "sys_setreuid",
	unix.SYS_SETREGID:                "sys_setregid",
	unix.SYS_GETGROUPS:               "sys_getgroups",
	unix.SYS_SETGROUPS:               "sys_setgroups",
	unix.SYS_SETRESUID:               "sys_setresuid",
	unix.SYS_GETRESUID:               "sys_getresuid",
	unix.SYS_SETRESGID:               "sys_setresgid",
	unix.SYS_GETRESGID:               "sys_getresgid",
	unix.SYS_GETPGID:                 "sys_getpgid",
	unix.SYS_SETFSUID:                "sys_setfsuid",
	unix.SYS_SETFSGID:                "sys_setfsgid",
	unix.SYS_GETSID:                  "sys_getsid",
	unix.SYS_CAPGET:                  "sys_capget",
	unix.SYS_CAPSET:                  "sys_capset",
	unix.SYS_RT_SIGPENDING:           "sys_rt_sigpending",
	unix.SYS_RT_SIGTIMEDWAIT:         "sys_rt_sigtimedwait",
	unix.SYS_RT_SIGQUEUEINFO:         "sys_rt_sigqueueinfo",
	unix.SYS_RT_SIGSUSPEND:           "sys_rt_sigsuspend",
	unix.SYS_SIGALTSTACK:             "sys_sigaltstack",
	unix.SYS_UTIME:                   "sys_utime",
	unix.SYS_MKNOD:                   "sys_mknod",
	unix.SYS_USELIB:                  "sys_uselib",
	unix.SYS_PERSONALITY:             "sys_personality",
	unix.SYS_USTAT:                   "sys_ustat",
	unix.SYS_STATFS:                  "sys_statfs",
	unix.SYS_FSTATFS:                 "sys_fstatfs",
	unix.SYS_SYSFS:                   "sys_sysfs",
	unix.SYS_GETPRIORITY:             "sys_getpriority",
	unix.SYS_SETPRIORITY:             "sys_setpriority",
	unix.SYS_SCHED_SETPARAM:          "sys_sched_setparam",
	unix.SYS_SCHED_GETPARAM:          "sys_sched_getparam",
	unix.SYS_SCHED_SETSCHEDULER:      "sys_sched_setscheduler",
	unix.SYS_SCHED_GETSCHEDULER:      "sys_sched_getscheduler",
	unix.SYS_SCHED_GET_PRIORITY_MAX:  "sys_sched_get_priority_max",
	unix.SYS_SCHED_GET_PRIORITY_MIN:  "sys_sched_get_priority_min",
	unix.SYS_SCHED_RR_GET_INTERVAL:   "sys_sched_rr_get_interval",
	unix.SYS_MLOCK:                   "sys_mlock",
	unix.SYS_MUNLOCK:                 "sys_munlock",
	unix.SYS_MLOCKALL:                "sys_mlockall",
	unix.SYS_MUNLOCKALL:              "sys_munlockall",
	unix.SYS_VHANGUP:                 "sys_vhangup",
	unix.SYS_MODIFY_LDT:              "sys_modify_ldt",
	unix.SYS_PIVOT_ROOT:              "sys_pivot_root",
	unix.SYS__SYSCTL:                 "sys__sysctl",
	unix.SYS_PRCTL:                   "sys_prctl",
	unix.SYS_ARCH_PRCTL:              "sys_arch_prctl",
	unix.SYS_ADJTIMEX:                "sys_adjtimex",
	unix.SYS_SETRLIMIT:               "sys_setrlimit",
	unix.SYS_CHROOT:                  "sys_chroot",
	unix.SYS_SYNC:                    "sys_sync",
	unix.SYS_ACCT:                    "sys_acct",
	unix.SYS_SETTIMEOFDAY:            "sys_settimeofday",
	unix.SYS_MOUNT:                   "sys_mount",
	unix.SYS_UMOUNT2:                 "sys_umount2",
	unix.SYS_SWAPON:                  "sys_swapon",
	unix.SYS_SWAPOFF:                 "sys_swapoff",
	unix.SYS_REBOOT:                  "sys_reboot",
	unix.SYS_SETHOSTNAME:             "sys_sethostname",
	unix.SYS_SETDOMAINNAME:           "sys_setdomainname",
	unix.SYS_IOPL:                    "sys_iopl",
	unix.SYS_IOPERM:                  "sys_ioperm",
	unix.SYS_CREATE_MODULE:           "sys_create_module",
	unix.SYS_INIT_MODULE:             "sys_init_module",
	unix.SYS_DELETE_MODULE:           "sys_delete_module",
	unix.SYS_GET_KERNEL_SYMS:         "sys_get_kernel_syms",
	unix.SYS_QUERY_MODULE:            "sys_query_module",
	unix.SYS_QUOTACTL:                "sys_quotactl",
	unix.SYS_NFSSERVCTL:              "sys_nfsservctl",
	unix.SYS_GETPMSG:                 "sys_getpmsg",
	unix.SYS_PUTPMSG:                 "sys_putpmsg",
	unix.SYS_AFS_SYSCALL:             "sys_afs_syscall",
	unix.SYS_TUXCALL:                 "sys_tuxcall",
	unix.SYS_SECURITY:                "sys_security",
	unix.SYS_GETTID:                  "sys_gettid",
	unix.SYS_READAHEAD:               "sys_readahead",
	unix.SYS_SETXATTR:                "sys_setxattr",
	unix.SYS_LSETXATTR:               "sys_lsetxattr",
	unix.SYS_FSETXATTR:               "sys_fsetxattr",
	unix.SYS_GETXATTR:                "sys_getxattr",
	unix.SYS_LGETXATTR:               "sys_lgetxattr",
	unix.SYS_FGETXATTR:               "sys_fgetxattr",
	unix.SYS_LISTXATTR:               "sys_listxattr",
	unix.SYS_LLISTXATTR:              "sys_llistxattr",
	unix.SYS_FLISTXATTR:              "sys_flistxattr",
	unix.SYS_REMOVEXATTR:             "sys_removexattr",
	unix.SYS_LREMOVEXATTR:            "sys_lremovexattr",
	unix.SYS_FREMOVEXATTR:            "sys_fremovexattr",
	unix.SYS_TKILL:                   "sys_tkill",
	unix.SYS_TIME:                    "sys_time",
	unix.SYS_FUTEX:                   "sys_futex",
	unix.SYS_SCHED_SETAFFINITY:       "sys_sched_setaffinity",
	unix.SYS_SCHED_GETAFFINITY:       "sys_sched_getaffinity",
	unix.SYS_SET_THREAD_AREA:         "sys_set_thread_area",
	unix.SYS_IO_SETUP:                "sys_io_setup",
	unix.SYS_IO_DESTROY:              "sys_io_destroy",
	unix.SYS_IO_GETEVENTS:            "sys_io_getevents",
	unix.SYS_IO_SUBMIT:               "sys_io_submit",
	unix.SYS_IO_CANCEL:               "sys_io_cancel",
	unix.SYS_GET_THREAD_AREA:         "sys_get_thread_area",
	unix.SYS_LOOKUP_DCOOKIE:          "sys_lookup_dcookie",
	unix.SYS_EPOLL_CREATE:            "sys_epoll_create",
	unix.SYS_EPOLL_CTL_OLD:           "sys_epoll_ctl_old",
	unix.SYS_EPOLL_WAIT_OLD:          "sys_epoll_wait_old",
	unix.SYS_REMAP_FILE_PAGES:        "sys_remap_file_pages",
	unix.SYS_GETDENTS64:              "sys_getdents64",
	unix.SYS_SET_TID_ADDRESS:         "sys_set_tid_address",
	unix.SYS_RESTART_SYSCALL:         "sys_restart_syscall",
	unix.SYS_SEMTIMEDOP:              "sys_semtimedop",
	unix.SYS_FADVISE64:               "sys_fadvise64",
	unix.SYS_TIMER_CREATE:            "sys_timer_create",
	unix.SYS_TIMER_SETTIME:           "sys_timer_settime",
	unix.SYS_TIMER_GETTIME:           "sys_timer_gettime",
	unix.SYS_TIMER_GETOVERRUN:        "sys_timer_getoverrun",
	unix.SYS_TIMER_DELETE:            "sys_timer_delete",
	unix.SYS_CLOCK_SETTIME:           "sys_clock_settime",
	unix.SYS_CLOCK_GETTIME:           "sys_clock_gettime",
	unix.SYS_CLOCK_GETRES:            "sys_clock_getres",
	unix.SYS_CLOCK_NANOSLEEP:         "sys_clock_nanosleep",
	unix.SYS_EXIT_GROUP:              "sys_exit_group",
	unix.SYS_EPOLL_WAIT:              "sys_epoll_wait",
	unix.SYS_EPOLL_CTL:               "sys_epoll_ctl",
	unix.SYS_TGKILL:                  "sys_tgkill",
	unix.SYS_UTIMES:                  "sys_utimes",
	unix.SYS_VSERVER:                 "sys_vserver",
	unix.SYS_MBIND:                   "sys_mbind",
	unix.SYS_SET_MEMPOLICY:           "sys_set_mempolicy",
	unix.SYS_GET_MEMPOLICY:           "sys_get_mempolicy",
	unix.SYS_MQ_OPEN:                 "sys_mq_open",
	unix.SYS_MQ_UNLINK:               "sys_mq_unlink",
	unix.SYS_MQ_TIMEDSEND:            "sys_mq_timedsend",
	unix.SYS_MQ_TIMEDRECEIVE:         "sys_mq_timedreceive",
	unix.SYS_MQ_NOTIFY:               "sys_mq_notify",
	unix.SYS_MQ_GETSETATTR:           "sys_mq_getsetattr",
	unix.SYS_KEXEC_LOAD:              "sys_kexec_load",
	unix.SYS_WAITID:                  "sys_waitid",
	unix.SYS_ADD_KEY:                 "sys_add_key",
	unix.SYS_REQUEST_KEY:             "sys_request_key",
	unix.SYS_KEYCTL:                  "sys_keyctl",
	unix.SYS_IOPRIO_SET:              "sys_ioprio_set",
	unix.SYS_IOPRIO_GET:              "sys_ioprio_get",
	unix.SYS_INOTIFY_INIT:            "sys_inotify_init",
	unix.SYS_INOTIFY_ADD_WATCH:       "sys_inotify_add_watch",
	unix.SYS_INOTIFY_RM_WATCH:        "sys_inotify_rm_watch",
	unix.SYS_MIGRATE_PAGES:           "sys_migrate_pages",
	unix.SYS_OPENAT:                  "sys_openat",
	unix.SYS_MKDIRAT:                 "sys_mkdirat",
	unix.SYS_MKNODAT:                 "sys_mknodat",
	unix.SYS_FCHOWNAT:                "sys_fchownat",
	unix.SYS_FUTIMESAT:               "sys_futimesat",
	unix.SYS_NEWFSTATAT:              "sys_newfstatat",
	unix.SYS_UNLINKAT:                "sys_unlinkat",
	unix.SYS_RENAMEAT:                "sys_renameat",
	unix.SYS_LINKAT:                  "sys_linkat",
	unix.SYS_SYMLINKAT:               "sys_symlinkat",
	unix.SYS_READLINKAT:              "sys_readlinkat",
	unix.SYS_FCHMODAT:                "sys_fchmodat",
	unix.SYS_FACCESSAT:               "sys_faccessat",
	unix.SYS_PSELECT6:                "sys_pselect6",
	unix.SYS_PPOLL:                   "sys_ppoll",
	unix.SYS_UNSHARE:                 "sys_unshare",
	unix.SYS_SET_ROBUST_LIST:         "sys_set_robust_list",
	unix.SYS_GET_ROBUST_LIST:         "sys_get_robust_list",
	unix.SYS_SPLICE:                  "sys_splice",
	unix.SYS_TEE:                     "sys_tee",
	unix.SYS_SYNC_FILE_RANGE:         "sys_sync_file_range",
	unix.SYS_VMSPLICE:                "sys_vmsplice",
	unix.SYS_MOVE_PAGES:              "sys_move_pages",
	unix.SYS_UTIMENSAT:               "sys_utimensat",
	unix.SYS_EPOLL_PWAIT:             "sys_epoll_pwait",
	unix.SYS_SIGNALFD:                "sys_signalfd",
	unix.SYS_TIMERFD_CREATE:          "sys_timerfd_create",
	unix.SYS_EVENTFD:                 "sys_eventfd",
	unix.SYS_FALLOCATE:               "sys_fallocate",
	unix.SYS_TIMERFD_SETTIME:         "sys_timerfd_settime",
	unix.SYS_TIMERFD_GETTIME:         "sys_timerfd_gettime",
	unix.SYS_ACCEPT4:                 "sys_accept4",
	unix.SYS_SIGNALFD4:               "sys_signalfd4",
	unix.SYS_EVENTFD2:                "sys_eventfd2",
	unix.SYS_EPOLL_CREATE1:           "sys_epoll_create1",
	unix.SYS_DUP3:                    "sys_dup3",
	unix.SYS_PIPE2:                   "sys_pipe2",
	unix.SYS_INOTIFY_INIT1:           "sys_inotify_init1",
	unix.SYS_PREADV:                  "sys_preadv",
	unix.SYS_PWRITEV:                 "sys_pwritev",
	unix.SYS_RT_TGSIGQUEUEINFO:       "sys_rt_tgsigqueueinfo",
	unix.SYS_PERF_EVENT_OPEN:         "sys_perf_event_open",
	unix.SYS_RECVMMSG:                "sys_recvmmsg",
	unix.SYS_FANOTIFY_INIT:           "sys_fanotify_init",
	unix.SYS_FANOTIFY_MARK:           "sys_fanotify_mark",
	unix.SYS_PRLIMIT64:               "sys_prlimit64",
	unix.SYS_NAME_TO_HANDLE_AT:       "sys_name_to_handle_at",
	unix.SYS_OPEN_BY_HANDLE_AT:       "sys_open_by_handle_at",
	unix.SYS_CLOCK_ADJTIME:           "sys_clock_adjtime",
	unix.SYS_SYNCFS:                  "sys_syncfs",
	unix.SYS_SENDMMSG:                "sys_sendmmsg",
	unix.SYS_SETNS:                   "sys_setns",
	unix.SYS_GETCPU:                  "sys_getcpu",
	unix.SYS_PROCESS_VM_READV:        "sys_process_vm_readv",
	unix.SYS_PROCESS_VM_WRITEV:       "sys_process_vm_writev",
	unix.SYS_KCMP:                    "sys_kcmp",
	unix.SYS_FINIT_MODULE:            "sys_finit_module",
	unix.SYS_SCHED_SETATTR:           "sys_sched_setattr",
	unix.SYS_SCHED_GETATTR:           "sys_sched_getattr",
	unix.SYS_RENAMEAT2:               "sys_renameat2",
	unix.SYS_SECCOMP:                 "sys_seccomp",
	unix.SYS_GETRANDOM:               "sys_getrandom",
	unix.SYS_MEMFD_CREATE:            "sys_memfd_create",
	unix.SYS_KEXEC_FILE_LOAD:         "sys_kexec_file_load",
	unix.SYS_BPF:                     "sys_bpf",
	unix.SYS_EXECVEAT:                "sys_execveat",
	unix.SYS_USERFAULTFD:             "sys_userfaultfd",
	unix.SYS_MEMBARRIER:              "sys_membarrier",
	unix.SYS_MLOCK2:                  "sys_mlock2",
	unix.SYS_COPY_FILE_RANGE:         "sys_copy_file_range",
	unix.SYS_PREADV2:                 "sys_preadv2",
	unix.SYS_PWRITEV2:                "sys_pwritev2",
	unix.SYS_PKEY_MPROTECT:           "sys_pkey_mprotect",
	unix.SYS_PKEY_ALLOC:              "sys_pkey_alloc",
	unix.SYS_PKEY_FREE:               "sys_pkey_free",
	unix.SYS_STATX:                   "sys_statx",
	unix.SYS_IO_PGETEVENTS:           "sys_io_pgetevents",
	unix.SYS_RSEQ:                    "sys_rseq",
	unix.SYS_PIDFD_SEND_SIGNAL:       "sys_pidfd_send_signal",
	unix.SYS_IO_URING_SETUP:          "sys_io_uring_setup",
	unix.SYS_IO_URING_ENTER:          "sys_io_uring_enter",
	unix.SYS_IO_URING_REGISTER:       "sys_io_uring_register",
	unix.SYS_OPEN_TREE:               "sys_open_tree",
	unix.SYS_MOVE_MOUNT:              "sys_move_mount",
	unix.SYS_FSOPEN:                  "sys_fsopen",
	unix.SYS_FSCONFIG:                "sys_fsconfig",
	unix.SYS_FSMOUNT:                 "sys_fsmount",
	unix.SYS_FSPICK:                  "sys_fspick",
	unix.SYS_PIDFD_OPEN:              "sys_pidfd_open",
	unix.SYS_CLONE3:                  "sys_clone3",
	unix.SYS_CLOSE_RANGE:             "sys_close_range",
	unix.SYS_OPENAT2:                 "sys_openat2",
	unix.SYS_PIDFD_GETFD:             "sys_pidfd_getfd",
	unix.SYS_FACCESSAT2:              "sys_faccessat2",
	unix.SYS_PROCESS_MADVISE:         "sys_process_madvise",
	unix.SYS_EPOLL_PWAIT2:            "sys_epoll_pwait2",
	unix.SYS_MOUNT_SETATTR:           "sys_mount_setattr",
	unix.SYS_QUOTACTL_FD:             "sys_quotactl_fd",
	unix.SYS_LANDLOCK_CREATE_RULESET: "sys_landlock_create_ruleset",
	unix.SYS_LANDLOCK_ADD_RULE:       "sys_landlock_add_rule",
	unix.SYS_LANDLOCK_RESTRICT_SELF:  "sys_landlock_restrict_self",
	unix.SYS_MEMFD_SECRET:            "sys_memfd_secret",
	unix.SYS_PROCESS_MRELEASE:        "sys_process_mrelease",
	// unix.SYS_FUTEX_WAITV:             "sys_futex_waitv",
	// unix.SYS_SET_MEMPOLICY_HOME_NODE: "sys_set_mempolicy_home_node",
}

var syscallNames32 = map[int]string{
	i386.SYS_RESTART_SYSCALL:              "sys_restart_syscall",
	i386.SYS_EXIT:                         "sys_exit",
	i386.SYS_FORK:                         "sys_fork",
	i386.SYS_READ:                         "sys_read",
	i386.SYS_WRITE:                        "sys_write",
	i386.SYS_OPEN:                         "sys_open",
	i386.SYS_CLOSE:                        "sys_close",
	i386.SYS_WAITPID:                      "sys_waitpid",
	i386.SYS_CREAT:                        "sys_creat",
	i386.SYS_LINK:                         "sys_link",
	i386.SYS_UNLINK:                       "sys_unlink",
	i386.SYS_EXECVE:                       "sys_execve",
	i386.SYS_CHDIR:                        "sys_chdir",
	i386.SYS_TIME:                         "sys_time",
	i386.SYS_MKNOD:                        "sys_mknod",
	i386.SYS_CHMOD:                        "sys_chmod",
	i386.SYS_LCHOWN:                       "sys_lchown",
	i386.SYS_BREAK:                        "sys_break",
	i386.SYS_OLDSTAT:                      "sys_oldstat",
	i386.SYS_LSEEK:                        "sys_lseek",
	i386.SYS_GETPID:                       "sys_getpid",
	i386.SYS_MOUNT:                        "sys_mount",
	i386.SYS_UMOUNT:                       "sys_umount",
	i386.SYS_SETUID:                       "sys_setuid",
	i386.SYS_GETUID:                       "sys_getuid",
	i386.SYS_STIME:                        "sys_stime",
	i386.SYS_PTRACE:                       "sys_ptrace",
	i386.SYS_ALARM:                        "sys_alarm",
	i386.SYS_OLDFSTAT:                     "sys_oldfstat",
	i386.SYS_PAUSE:                        "sys_pause",
	i386.SYS_UTIME:                        "sys_utime",
	i386.SYS_STTY:                         "sys_stty",
	i386.SYS_GTTY:                         "sys_gtty",
	i386.SYS_ACCESS:                       "sys_access",
	i386.SYS_NICE:                         "sys_nice",
	i386.SYS_FTIME:                        "sys_ftime",
	i386.SYS_SYNC:                         "sys_sync",
	i386.SYS_KILL:                         "sys_kill",
	i386.SYS_RENAME:                       "sys_rename",
	i386.SYS_MKDIR:                        "sys_mkdir",
	i386.SYS_RMDIR:                        "sys_rmdir",
	i386.SYS_DUP:                          "sys_dup",
	i386.SYS_PIPE:                         "sys_pipe",
	i386.SYS_TIMES:                        "sys_times",
	i386.SYS_PROF:                         "sys_prof",
	i386.SYS_BRK:                          "sys_brk",
	i386.SYS_SETGID:                       "sys_setgid",
	i386.SYS_GETGID:                       "sys_getgid",
	i386.SYS_SIGNAL:                       "sys_signal",
	i386.SYS_GETEUID:                      "sys_geteuid",
	i386.SYS_GETEGID:                      "sys_getegid",
	i386.SYS_ACCT:                         "sys_acct",
	i386.SYS_UMOUNT2:                      "sys_umount2",
	i386.SYS_LOCK:                         "sys_lock",
	i386.SYS_IOCTL:                        "sys_ioctl",
	i386.SYS_FCNTL:                        "sys_fcntl",
	i386.SYS_MPX:                          "sys_mpx",
	i386.SYS_SETPGID:                      "sys_setpgid",
	i386.SYS_ULIMIT:                       "sys_ulimit",
	i386.SYS_OLDOLDUNAME:                  "sys_oldolduname",
	i386.SYS_UMASK:                        "sys_umask",
	i386.SYS_CHROOT:                       "sys_chroot",
	i386.SYS_USTAT:                        "sys_ustat",
	i386.SYS_DUP2:                         "sys_dup2",
	i386.SYS_GETPPID:                      "sys_getppid",
	i386.SYS_GETPGRP:                      "sys_getpgrp",
	i386.SYS_SETSID:                       "sys_setsid",
	i386.SYS_SIGACTION:                    "sys_sigaction",
	i386.SYS_SGETMASK:                     "sys_sgetmask",
	i386.SYS_SSETMASK:                     "sys_ssetmask",
	i386.SYS_SETREUID:                     "sys_setreuid",
	i386.SYS_SETREGID:                     "sys_setregid",
	i386.SYS_SIGSUSPEND:                   "sys_sigsuspend",
	i386.SYS_SIGPENDING:                   "sys_sigpending",
	i386.SYS_SETHOSTNAME:                  "sys_sethostname",
	i386.SYS_SETRLIMIT:                    "sys_setrlimit",
	i386.SYS_GETRLIMIT:                    "sys_getrlimit",
	i386.SYS_GETRUSAGE:                    "sys_getrusage",
	i386.SYS_GETTIMEOFDAY:                 "sys_gettimeofday",
	i386.SYS_SETTIMEOFDAY:                 "sys_settimeofday",
	i386.SYS_GETGROUPS:                    "sys_getgroups",
	i386.SYS_SETGROUPS:                    "sys_setgroups",
	i386.SYS_SELECT:                       "sys_select",
	i386.SYS_SYMLINK:                      "sys_symlink",
	i386.SYS_OLDLSTAT:                     "sys_oldstat",
	i386.SYS_READLINK:                     "sys_readlink",
	i386.SYS_USELIB:                       "sys_uselib",
	i386.SYS_SWAPON:                       "sys_swapon",
	i386.SYS_REBOOT:                       "sys_reboot",
	i386.SYS_READDIR:                      "sys_readdir",
	i386.SYS_MMAP:                         "sys_mmap",
	i386.SYS_MUNMAP:                       "sys_munmap",
	i386.SYS_TRUNCATE:                     "sys_truncate",
	i386.SYS_FTRUNCATE:                    "sys_ftruncate",
	i386.SYS_FCHMOD:                       "sys_fchmod",
	i386.SYS_FCHOWN:                       "sys_fchown",
	i386.SYS_GETPRIORITY:                  "sys_getpriority",
	i386.SYS_SETPRIORITY:                  "sys_setpriority",
	i386.SYS_PROFIL:                       "sys_profil",
	i386.SYS_STATFS:                       "sys_statfs",
	i386.SYS_FSTATFS:                      "sys_fstatfs",
	i386.SYS_IOPERM:                       "sys_ioperm",
	i386.SYS_SOCKETCALL:                   "sys_socketcall",
	i386.SYS_SYSLOG:                       "sys_syslog",
	i386.SYS_SETITIMER:                    "sys_setitimer",
	i386.SYS_GETITIMER:                    "sys_getitimer",
	i386.SYS_STAT:                         "sys_stat",
	i386.SYS_LSTAT:                        "sys_lstat",
	i386.SYS_FSTAT:                        "sys_fstat",
	i386.SYS_OLDUNAME:                     "sys_olduname",
	i386.SYS_IOPL:                         "sys_iopl",
	i386.SYS_VHANGUP:                      "sys_vhangup",
	i386.SYS_IDLE:                         "sys_idle",
	i386.SYS_VM86OLD:                      "sys_vm86old",
	i386.SYS_WAIT4:                        "sys_wait4",
	i386.SYS_SWAPOFF:                      "sys_swapoff",
	i386.SYS_SYSINFO:                      "sys_sysinfo",
	i386.SYS_IPC:                          "sys_ipc",
	i386.SYS_FSYNC:                        "sys_fsync",
	i386.SYS_SIGRETURN:                    "sys_sigreturn",
	i386.SYS_CLONE:                        "sys_clone",
	i386.SYS_SETDOMAINNAME:                "sys_setdomainname",
	i386.SYS_UNAME:                        "sys_uname",
	i386.SYS_MODIFY_LDT:                   "sys_modify_ldt",
	i386.SYS_ADJTIMEX:                     "sys_adjtimex",
	i386.SYS_MPROTECT:                     "sys_mprotect",
	i386.SYS_SIGPROCMASK:                  "sys_sigprocmask",
	i386.SYS_CREATE_MODULE:                "sys_create_module",
	i386.SYS_INIT_MODULE:                  "sys_init_module",
	i386.SYS_DELETE_MODULE:                "sys_delete_module",
	i386.SYS_GET_KERNEL_SYMS:              "sys_get_kernel_syms",
	i386.SYS_QUOTACTL:                     "sys_quotactl",
	i386.SYS_GETPGID:                      "sys_getpgid",
	i386.SYS_FCHDIR:                       "sys_fchdir",
	i386.SYS_BDFLUSH:                      "sys_bdflush",
	i386.SYS_SYSFS:                        "sys_sysfs",
	i386.SYS_PERSONALITY:                  "sys_personality",
	i386.SYS_AFS_SYSCALL:                  "sys_afs_syscall",
	i386.SYS_SETFSUID:                     "sys_setfsuid",
	i386.SYS_SETFSGID:                     "sys_setfsgid",
	i386.SYS__LLSEEK:                      "sys__llseek",
	i386.SYS_GETDENTS:                     "sys_getdents",
	i386.SYS__NEWSELECT:                   "sys__newselect",
	i386.SYS_FLOCK:                        "sys_flock",
	i386.SYS_MSYNC:                        "sys_msync",
	i386.SYS_READV:                        "sys_readv",
	i386.SYS_WRITEV:                       "sys_writev",
	i386.SYS_GETSID:                       "sys_getsid",
	i386.SYS_FDATASYNC:                    "sys_fdatasync",
	i386.SYS__SYSCTL:                      "sys__sysctl",
	i386.SYS_MLOCK:                        "sys_mlock",
	i386.SYS_MUNLOCK:                      "sys_munlock",
	i386.SYS_MLOCKALL:                     "sys_mlockall",
	i386.SYS_MUNLOCKALL:                   "sys_munlockall",
	i386.SYS_SCHED_SETPARAM:               "sys_sched_setparam",
	i386.SYS_SCHED_GETPARAM:               "sys_sched_getparam",
	i386.SYS_SCHED_SETSCHEDULER:           "sys_sched_setscheduler",
	i386.SYS_SCHED_GETSCHEDULER:           "sys_sched_getscheduler",
	i386.SYS_SCHED_YIELD:                  "sys_sched_yield",
	i386.SYS_SCHED_GET_PRIORITY_MAX:       "sys_sched_get_priority_max",
	i386.SYS_SCHED_GET_PRIORITY_MIN:       "sys_sched_get_priority_min",
	i386.SYS_SCHED_RR_GET_INTERVAL:        "sys_sched_rr_get_interval",
	i386.SYS_NANOSLEEP:                    "sys_nanosleep",
	i386.SYS_MREMAP:                       "sys_mremap",
	i386.SYS_SETRESUID:                    "sys_setresuid",
	i386.SYS_GETRESUID:                    "sys_getresuid",
	i386.SYS_VM86:                         "sys_vm86",
	i386.SYS_QUERY_MODULE:                 "sys_query_module",
	i386.SYS_POLL:                         "sys_poll",
	i386.SYS_NFSSERVCTL:                   "sys_nfsservctl",
	i386.SYS_SETRESGID:                    "sys_setresgid",
	i386.SYS_GETRESGID:                    "sys_getresgid",
	i386.SYS_PRCTL:                        "sys_prctl",
	i386.SYS_RT_SIGRETURN:                 "sys_rt_sigreturn",
	i386.SYS_RT_SIGACTION:                 "sys_rt_sigaction",
	i386.SYS_RT_SIGPROCMASK:               "sys_rt_sigprocmask",
	i386.SYS_RT_SIGPENDING:                "sys_rt_sigpending",
	i386.SYS_RT_SIGTIMEDWAIT:              "sys_rt_sigtimedwait",
	i386.SYS_RT_SIGQUEUEINFO:              "sys_rt_sigqueueinfo",
	i386.SYS_RT_SIGSUSPEND:                "sys_rt_sigsuspend",
	i386.SYS_PREAD64:                      "sys_pread64",
	i386.SYS_PWRITE64:                     "sys_pwrite64",
	i386.SYS_CHOWN:                        "sys_chown",
	i386.SYS_GETCWD:                       "sys_getcwd",
	i386.SYS_CAPGET:                       "sys_capget",
	i386.SYS_CAPSET:                       "sys_capset",
	i386.SYS_SIGALTSTACK:                  "sys_sigaltstack",
	i386.SYS_SENDFILE:                     "sys_sendfile",
	i386.SYS_GETPMSG:                      "sys_getpmsg",
	i386.SYS_PUTPMSG:                      "sys_putpmsg",
	i386.SYS_VFORK:                        "sys_vfork",
	i386.SYS_UGETRLIMIT:                   "sys_ugetrlimit",
	i386.SYS_MMAP2:                        "sys_mmap2",
	i386.SYS_TRUNCATE64:                   "sys_truncate64",
	i386.SYS_FTRUNCATE64:                  "sys_ftruncate64",
	i386.SYS_STAT64:                       "sys_stat64",
	i386.SYS_LSTAT64:                      "sys_lstat64",
	i386.SYS_FSTAT64:                      "sys_fstat64",
	i386.SYS_LCHOWN32:                     "sys_lchown32",
	i386.SYS_GETUID32:                     "sys_getuid32",
	i386.SYS_GETGID32:                     "sys_getgid32",
	i386.SYS_GETEUID32:                    "sys_geteuid32",
	i386.SYS_GETEGID32:                    "sys_getegid32",
	i386.SYS_SETREUID32:                   "sys_setreuid32",
	i386.SYS_SETREGID32:                   "sys_setregid32",
	i386.SYS_GETGROUPS32:                  "sys_getgroups32",
	i386.SYS_SETGROUPS32:                  "sys_setgroups32",
	i386.SYS_FCHOWN32:                     "sys_fchown32",
	i386.SYS_SETRESUID32:                  "sys_setresuid32",
	i386.SYS_GETRESUID32:                  "sys_getresuid32",
	i386.SYS_SETRESGID32:                  "sys_setresgid32",
	i386.SYS_GETRESGID32:                  "sys_getresgid32",
	i386.SYS_CHOWN32:                      "sys_chown32",
	i386.SYS_SETUID32:                     "sys_setuid32",
	i386.SYS_SETGID32:                     "sys_setgid32",
	i386.SYS_SETFSUID32:                   "sys_setfsuid32",
	i386.SYS_SETFSGID32:                   "sys_setfsgid32",
	i386.SYS_PIVOT_ROOT:                   "sys_pivot_root",
	i386.SYS_MINCORE:                      "sys_mincore",
	i386.SYS_MADVISE:                      "sys_madvise",
	i386.SYS_GETDENTS64:                   "sys_getdents64",
	i386.SYS_FCNTL64:                      "sys_fcntl64",
	i386.SYS_GETTID:                       "sys_gettid",
	i386.SYS_READAHEAD:                    "sys_readahead",
	i386.SYS_SETXATTR:                     "sys_setxattr",
	i386.SYS_LSETXATTR:                    "sys_lsetxattr",
	i386.SYS_FSETXATTR:                    "sys_fsetxattr",
	i386.SYS_GETXATTR:                     "sys_getxattr",
	i386.SYS_LGETXATTR:                    "sys_lgetxattr",
	i386.SYS_FGETXATTR:                    "sys_fgetxattr",
	i386.SYS_LISTXATTR:                    "sys_listxattr",
	i386.SYS_LLISTXATTR:                   "sys_llistxattr",
	i386.SYS_FLISTXATTR:                   "sys_flistxattr",
	i386.SYS_REMOVEXATTR:                  "sys_removexattr",
	i386.SYS_LREMOVEXATTR:                 "sys_lremovexattr",
	i386.SYS_FREMOVEXATTR:                 "sys_fremovexattr",
	i386.SYS_TKILL:                        "sys_tkill",
	i386.SYS_SENDFILE64:                   "sys_sendfile64",
	i386.SYS_FUTEX:                        "sys_futex",
	i386.SYS_SCHED_SETAFFINITY:            "sys_sched_setaffinity",
	i386.SYS_SCHED_GETAFFINITY:            "sys_sched_getaffinity",
	i386.SYS_SET_THREAD_AREA:              "sys_set_thread_area",
	i386.SYS_GET_THREAD_AREA:              "sys_get_thread_area",
	i386.SYS_IO_SETUP:                     "sys_io_setup",
	i386.SYS_IO_DESTROY:                   "sys_io_destroy",
	i386.SYS_IO_GETEVENTS:                 "sys_io_getevents",
	i386.SYS_IO_SUBMIT:                    "sys_io_submit",
	i386.SYS_IO_CANCEL:                    "sys_io_cancel",
	i386.SYS_FADVISE64:                    "sys_fadvise64",
	i386.SYS_EXIT_GROUP:                   "sys_exit_group",
	i386.SYS_LOOKUP_DCOOKIE:               "sys_lookup_dcookie",
	i386.SYS_EPOLL_CREATE:                 "sys_epoll_create",
	i386.SYS_EPOLL_CTL:                    "sys_epoll_ctl",
	i386.SYS_EPOLL_WAIT:                   "sys_epoll_wait",
	i386.SYS_REMAP_FILE_PAGES:             "sys_remap_file_pages",
	i386.SYS_SET_TID_ADDRESS:              "sys_set_tid_address",
	i386.SYS_TIMER_CREATE:                 "sys_timer_create",
	i386.SYS_TIMER_SETTIME:                "sys_timer_settime",
	i386.SYS_TIMER_GETTIME:                "sys_timer_gettime",
	i386.SYS_TIMER_GETOVERRUN:             "sys_timer_getoverrun",
	i386.SYS_TIMER_DELETE:                 "sys_timer_delete",
	i386.SYS_CLOCK_SETTIME:                "sys_clock_settime",
	i386.SYS_CLOCK_GETTIME:                "sys_clock_gettime",
	i386.SYS_CLOCK_GETRES:                 "sys_clock_getres",
	i386.SYS_CLOCK_NANOSLEEP:              "sys_clock_nanosleep",
	i386.SYS_STATFS64:                     "sys_statfs64",
	i386.SYS_FSTATFS64:                    "sys_fstatfs64",
	i386.SYS_TGKILL:                       "sys_tgkill",
	i386.SYS_UTIMES:                       "sys_utimes",
	i386.SYS_FADVISE64_64:                 "sys_fadvise64_64",
	i386.SYS_VSERVER:                      "sys_vserver",
	i386.SYS_MBIND:                        "sys_mbind",
	i386.SYS_GET_MEMPOLICY:                "sys_get_mempolicy",
	i386.SYS_SET_MEMPOLICY:                "sys_set_mempolicy",
	i386.SYS_MQ_OPEN:                      "sys_mq_open",
	i386.SYS_MQ_UNLINK:                    "sys_mq_unlink",
	i386.SYS_MQ_TIMEDSEND:                 "sys_mq_timedsend",
	i386.SYS_MQ_TIMEDRECEIVE:              "sys_mq_timedreceive",
	i386.SYS_MQ_NOTIFY:                    "sys_mq_notify",
	i386.SYS_MQ_GETSETATTR:                "sys_mq_getsetattr",
	i386.SYS_KEXEC_LOAD:                   "sys_kexec_load",
	i386.SYS_WAITID:                       "sys_waitid",
	i386.SYS_ADD_KEY:                      "sys_add_key",
	i386.SYS_REQUEST_KEY:                  "sys_request_key",
	i386.SYS_KEYCTL:                       "sys_keyctl",
	i386.SYS_IOPRIO_SET:                   "sys_ioprio_set",
	i386.SYS_IOPRIO_GET:                   "sys_ioprio_get",
	i386.SYS_INOTIFY_INIT:                 "sys_inotify_init",
	i386.SYS_INOTIFY_ADD_WATCH:            "sys_inotify_add_watch",
	i386.SYS_INOTIFY_RM_WATCH:             "sys_inotify_rm_watch",
	i386.SYS_MIGRATE_PAGES:                "sys_migrate_pages",
	i386.SYS_OPENAT:                       "sys_openat",
	i386.SYS_MKDIRAT:                      "sys_mkdirat",
	i386.SYS_MKNODAT:                      "sys_mknodat",
	i386.SYS_FCHOWNAT:                     "sys_fchownat",
	i386.SYS_FUTIMESAT:                    "sys_futimesat",
	i386.SYS_FSTATAT64:                    "sys_fstatat64",
	i386.SYS_UNLINKAT:                     "sys_unlinkat",
	i386.SYS_RENAMEAT:                     "sys_renameat",
	i386.SYS_LINKAT:                       "sys_linkat",
	i386.SYS_SYMLINKAT:                    "sys_symlinkat",
	i386.SYS_READLINKAT:                   "sys_readlinkat",
	i386.SYS_FCHMODAT:                     "sys_fchmodat",
	i386.SYS_FACCESSAT:                    "sys_faccessat",
	i386.SYS_PSELECT6:                     "sys_pselect6",
	i386.SYS_PPOLL:                        "sys_ppoll",
	i386.SYS_UNSHARE:                      "sys_unshare",
	i386.SYS_SET_ROBUST_LIST:              "sys_set_robust_list",
	i386.SYS_GET_ROBUST_LIST:              "sys_get_robust_list",
	i386.SYS_SPLICE:                       "sys_splice",
	i386.SYS_SYNC_FILE_RANGE:              "sys_sync_file_range",
	i386.SYS_TEE:                          "sys_tee",
	i386.SYS_VMSPLICE:                     "sys_vmsplice",
	i386.SYS_MOVE_PAGES:                   "sys_move_pages",
	i386.SYS_GETCPU:                       "sys_getcpu",
	i386.SYS_EPOLL_PWAIT:                  "sys_epoll_pwait",
	i386.SYS_UTIMENSAT:                    "sys_utimensat",
	i386.SYS_SIGNALFD:                     "sys_signalfd",
	i386.SYS_TIMERFD_CREATE:               "sys_timerfd_create",
	i386.SYS_EVENTFD:                      "sys_eventfd",
	i386.SYS_FALLOCATE:                    "sys_fallocate",
	i386.SYS_TIMERFD_SETTIME:              "sys_timerfd_settime",
	i386.SYS_TIMERFD_GETTIME:              "sys_timerfd_gettime",
	i386.SYS_SIGNALFD4:                    "sys_signalfd4",
	i386.SYS_EVENTFD2:                     "sys_eventfd2",
	i386.SYS_EPOLL_CREATE1:                "sys_epoll_create1",
	i386.SYS_DUP3:                         "sys_dup3",
	i386.SYS_PIPE2:                        "sys_pipe2",
	i386.SYS_INOTIFY_INIT1:                "sys_inotify_init1",
	i386.SYS_PREADV:                       "sys_preadv",
	i386.SYS_PWRITEV:                      "sys_pwritev",
	i386.SYS_RT_TGSIGQUEUEINFO:            "sys_rt_tgsigqueueinfo",
	i386.SYS_PERF_EVENT_OPEN:              "sys_perf_event_open",
	i386.SYS_RECVMMSG:                     "sys_recvmmsg",
	i386.SYS_FANOTIFY_INIT:                "sys_fanotify_init",
	i386.SYS_FANOTIFY_MARK:                "sys_fanotify_mark",
	i386.SYS_PRLIMIT64:                    "sys_prlimit64",
	i386.SYS_NAME_TO_HANDLE_AT:            "sys_name_to_handle_at",
	i386.SYS_OPEN_BY_HANDLE_AT:            "sys_open_by_handle_at",
	i386.SYS_CLOCK_ADJTIME:                "sys_clock_adjtime",
	i386.SYS_SYNCFS:                       "sys_syncfs",
	i386.SYS_SENDMMSG:                     "sys_sendmmsg",
	i386.SYS_SETNS:                        "sys_setns",
	i386.SYS_PROCESS_VM_READV:             "sys_process_vm_readv",
	i386.SYS_PROCESS_VM_WRITEV:            "sys_process_vm_writev",
	i386.SYS_KCMP:                         "sys_kcmp",
	i386.SYS_FINIT_MODULE:                 "sys_finit_module",
	i386.SYS_SCHED_SETATTR:                "sys_sched_setattr",
	i386.SYS_SCHED_GETATTR:                "sys_sched_getattr",
	i386.SYS_RENAMEAT2:                    "sys_renameat2",
	i386.SYS_SECCOMP:                      "sys_seccomp",
	i386.SYS_GETRANDOM:                    "sys_getrandom",
	i386.SYS_MEMFD_CREATE:                 "sys_memfd_create",
	i386.SYS_BPF:                          "sys_bpf",
	i386.SYS_EXECVEAT:                     "sys_execveat",
	i386.SYS_SOCKET:                       "sys_socket",
	i386.SYS_SOCKETPAIR:                   "sys_socketpair",
	i386.SYS_BIND:                         "sys_bind",
	i386.SYS_CONNECT:                      "sys_connect",
	i386.SYS_LISTEN:                       "sys_listen",
	i386.SYS_ACCEPT4:                      "sys_accept4",
	i386.SYS_GETSOCKOPT:                   "sys_getsockopt",
	i386.SYS_SETSOCKOPT:                   "sys_setsockopt",
	i386.SYS_GETSOCKNAME:                  "sys_getsockname",
	i386.SYS_GETPEERNAME:                  "sys_getpeername",
	i386.SYS_SENDTO:                       "sys_sendto",
	i386.SYS_SENDMSG:                      "sys_sendmsg",
	i386.SYS_RECVFROM:                     "sys_recvfrom",
	i386.SYS_RECVMSG:                      "sys_recvmsg",
	i386.SYS_SHUTDOWN:                     "sys_shutdown",
	i386.SYS_USERFAULTFD:                  "sys_userfaultfd",
	i386.SYS_MEMBARRIER:                   "sys_membarrier",
	i386.SYS_MLOCK2:                       "sys_mlock2",
	i386.SYS_COPY_FILE_RANGE:              "sys_copy_file_range",
	i386.SYS_PREADV2:                      "sys_preadv2",
	i386.SYS_PWRITEV2:                     "sys_pwritev2",
	i386.SYS_PKEY_MPROTECT:                "sys_pkey_mprotect",
	i386.SYS_PKEY_ALLOC:                   "sys_pkey_alloc",
	i386.SYS_PKEY_FREE:                    "sys_pkey_free",
	i386.SYS_STATX:                        "sys_statx",
	i386.SYS_ARCH_PRCTL:                   "sys_arch_prctl",
	i386.SYS_IO_PGETEVENTS:                "sys_io_pgetevents",
	i386.SYS_RSEQ:                         "sys_rseq",
	i386.SYS_SEMGET:                       "sys_semget",
	i386.SYS_SEMCTL:                       "sys_semctl",
	i386.SYS_SHMGET:                       "sys_shmget",
	i386.SYS_SHMCTL:                       "sys_shmctl",
	i386.SYS_SHMAT:                        "sys_shmat",
	i386.SYS_SHMDT:                        "sys_shmdt",
	i386.SYS_MSGGET:                       "sys_msgget",
	i386.SYS_MSGSND:                       "sys_msgsnd",
	i386.SYS_MSGRCV:                       "sys_msgrcv",
	i386.SYS_MSGCTL:                       "sys_msgctl",
	i386.SYS_CLOCK_GETTIME64:              "sys_clock_gettime64",
	i386.SYS_CLOCK_SETTIME64:              "sys_clock_settime64",
	i386.SYS_CLOCK_ADJTIME64:              "sys_clock_adjtime64",
	i386.SYS_CLOCK_GETRES_TIME64:          "sys_clock_getres_time64",
	i386.SYS_CLOCK_NANOSLEEP_TIME64:       "sys_clock_nanosleep_time64",
	i386.SYS_TIMER_GETTIME64:              "sys_timer_gettime64",
	i386.SYS_TIMER_SETTIME64:              "sys_timer_settime64",
	i386.SYS_TIMERFD_GETTIME64:            "sys_timerfd_gettime64",
	i386.SYS_TIMERFD_SETTIME64:            "sys_timerfd_settime64",
	i386.SYS_UTIMENSAT_TIME64:             "sys_utimensat_time64",
	i386.SYS_PSELECT6_TIME64:              "sys_pselect6_time64",
	i386.SYS_PPOLL_TIME64:                 "sys_ppoll_time64",
	i386.SYS_IO_PGETEVENTS_TIME64:         "sys_io_pgetevents_time64",
	i386.SYS_RECVMMSG_TIME64:              "sys_recvmsg_time64",
	i386.SYS_MQ_TIMEDSEND_TIME64:          "sys_mq_timedsend_time64",
	i386.SYS_MQ_TIMEDRECEIVE_TIME64:       "sys_mq_timedreceive_time64",
	i386.SYS_SEMTIMEDOP_TIME64:            "sys_semtimedop_time64",
	i386.SYS_RT_SIGTIMEDWAIT_TIME64:       "sys_rt_sigtimedwait_time64",
	i386.SYS_FUTEX_TIME64:                 "sys_futex_time64",
	i386.SYS_SCHED_RR_GET_INTERVAL_TIME64: "sys_sched_rr_get_interval_time64",
	i386.SYS_PIDFD_SEND_SIGNAL:            "sys_pidfd_send_signal",
	i386.SYS_IO_URING_SETUP:               "sys_io_uring_setup",
	i386.SYS_IO_URING_ENTER:               "sys_io_uring_enter",
	i386.SYS_IO_URING_REGISTER:            "sys_io_uring_register",
	i386.SYS_OPEN_TREE:                    "sys_open_tree",
	i386.SYS_MOVE_MOUNT:                   "sys_move_mount",
	i386.SYS_FSOPEN:                       "sys_fsopen",
	i386.SYS_FSCONFIG:                     "sys_fsconfig",
	i386.SYS_FSMOUNT:                      "sys_fsmount",
	i386.SYS_FSPICK:                       "sys_fspick",
	i386.SYS_PIDFD_OPEN:                   "sys_pidfd_open",
	i386.SYS_CLONE3:                       "sys_clone3",
	i386.SYS_CLOSE_RANGE:                  "sys_close_range",
	i386.SYS_OPENAT2:                      "sys_openat2",
	i386.SYS_PIDFD_GETFD:                  "sys_pidfd_getfd",
	i386.SYS_FACCESSAT2:                   "sys_faccessat2",
	i386.SYS_PROCESS_MADVISE:              "sys_process_madvise",
	i386.SYS_EPOLL_PWAIT2:                 "sys_epoll_pwait2",
	i386.SYS_MOUNT_SETATTR:                "sys_mount_setattr",
	i386.SYS_QUOTACTL_FD:                  "sys_quotactl_fd",
	i386.SYS_LANDLOCK_CREATE_RULESET:      "sys_landlock_create_ruleset",
	i386.SYS_LANDLOCK_ADD_RULE:            "sys_landlock_add_rule",
	i386.SYS_LANDLOCK_RESTRICT_SELF:       "sys_landlock_restrict_self",
	i386.SYS_MEMFD_SECRET:                 "sys_memfd_secret",
	i386.SYS_PROCESS_MRELEASE:             "sys_process_mrelease",
	i386.SYS_FUTEX_WAITV:                  "sys_futex_waitv",
	i386.SYS_SET_MEMPOLICY_HOME_NODE:      "sys_set_mempolicy_home_node",
	i386.SYS_CACHESTAT:                    "sys_cachestat",
	i386.SYS_FCHMODAT2:                    "sys_fchmodat2",
}
